@@ -297,13 +297,16 @@ class MongodbHelper(BaseSqlHelper):
                     total=total_result.get("total", 0) if total_result else 0).__dict__
 
     @echo_sql
-    def sync_execute_fetchone(self, sql: str, param=None):
+    def sync_execute_fetchone(self, sql: list, param=None):
         """
         查询单条数据
         :param sql: 待执行的Sql语句
         :param param: 参数
         :return:
         """
+        sql.append({
+            "$limit": 1
+        })
         cursor = param["collection"].aggregate(sql)
         rs = list(cursor)
         if len(rs) > 0:
